You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@camel.apache.org by da...@apache.org on 2022/08/10 04:27:20 UTC

[camel] branch main updated: Regen for commit a57b92774e7ebc16b2737acde40302c857ff1a0d (#8138)

This is an automated email from the ASF dual-hosted git repository.

davsclaus pushed a commit to branch main
in repository https://gitbox.apache.org/repos/asf/camel.git


The following commit(s) were added to refs/heads/main by this push:
     new 1bc076ffbe2 Regen for commit a57b92774e7ebc16b2737acde40302c857ff1a0d (#8138)
1bc076ffbe2 is described below

commit 1bc076ffbe2c86ace7ba0edc86365ebc1e240f76
Author: github-actions[bot] <41...@users.noreply.github.com>
AuthorDate: Wed Aug 10 06:27:13 2022 +0200

    Regen for commit a57b92774e7ebc16b2737acde40302c857ff1a0d (#8138)
    
    Signed-off-by: GitHub <no...@github.com>
    
    Co-authored-by: davsclaus <da...@users.noreply.github.com>
---
 .../builder/endpoint/StaticEndpointBuilders.java   | 12 ++++--
 .../endpoint/dsl/StreamEndpointBuilderFactory.java | 45 +++++++++++++++++++---
 2 files changed, 47 insertions(+), 10 deletions(-)

diff --git a/dsl/camel-endpointdsl/src/generated/java/org/apache/camel/builder/endpoint/StaticEndpointBuilders.java b/dsl/camel-endpointdsl/src/generated/java/org/apache/camel/builder/endpoint/StaticEndpointBuilders.java
index df074ca974f..7bab9aa4001 100644
--- a/dsl/camel-endpointdsl/src/generated/java/org/apache/camel/builder/endpoint/StaticEndpointBuilders.java
+++ b/dsl/camel-endpointdsl/src/generated/java/org/apache/camel/builder/endpoint/StaticEndpointBuilders.java
@@ -14287,8 +14287,10 @@ public class StaticEndpointBuilders {
      * Syntax: <code>stream:kind</code>
      * 
      * Path parameter: kind (required)
-     * Kind of stream to use such as System.in or System.out.
-     * There are 5 enums and the value can be one of: in, out, err, header, file
+     * Kind of stream to use such as System.in, System.out, a file, or a http
+     * url.
+     * There are 6 enums and the value can be one of: in, out, err, header,
+     * file, http
      * 
      * @param path kind
      * @return the dsl builder
@@ -14308,8 +14310,10 @@ public class StaticEndpointBuilders {
      * Syntax: <code>stream:kind</code>
      * 
      * Path parameter: kind (required)
-     * Kind of stream to use such as System.in or System.out.
-     * There are 5 enums and the value can be one of: in, out, err, header, file
+     * Kind of stream to use such as System.in, System.out, a file, or a http
+     * url.
+     * There are 6 enums and the value can be one of: in, out, err, header,
+     * file, http
      * 
      * @param componentName to use a custom component name for the endpoint
      * instead of the default name
diff --git a/dsl/camel-endpointdsl/src/generated/java/org/apache/camel/builder/endpoint/dsl/StreamEndpointBuilderFactory.java b/dsl/camel-endpointdsl/src/generated/java/org/apache/camel/builder/endpoint/dsl/StreamEndpointBuilderFactory.java
index 0b81058d568..1e834141b8c 100644
--- a/dsl/camel-endpointdsl/src/generated/java/org/apache/camel/builder/endpoint/dsl/StreamEndpointBuilderFactory.java
+++ b/dsl/camel-endpointdsl/src/generated/java/org/apache/camel/builder/endpoint/dsl/StreamEndpointBuilderFactory.java
@@ -170,6 +170,37 @@ public interface StreamEndpointBuilderFactory {
             doSetProperty("groupStrategy", groupStrategy);
             return this;
         }
+        /**
+         * When using stream:http format, this option specifies optional http
+         * headers, such as Accept: application/json. Multiple headers can be
+         * separated by comma.
+         * 
+         * The option is a: &lt;code&gt;java.lang.String&lt;/code&gt; type.
+         * 
+         * Group: consumer
+         * 
+         * @param httpHeaders the value to set
+         * @return the dsl builder
+         */
+        default StreamEndpointConsumerBuilder httpHeaders(String httpHeaders) {
+            doSetProperty("httpHeaders", httpHeaders);
+            return this;
+        }
+        /**
+         * When using stream:http format, this option specifies the http url to
+         * stream from.
+         * 
+         * The option is a: &lt;code&gt;java.lang.String&lt;/code&gt; type.
+         * 
+         * Group: consumer
+         * 
+         * @param httpUrl the value to set
+         * @return the dsl builder
+         */
+        default StreamEndpointConsumerBuilder httpUrl(String httpUrl) {
+            doSetProperty("httpUrl", httpUrl);
+            return this;
+        }
         /**
          * Initial delay in milliseconds before showing the message prompt. This
          * delay occurs only once. Can be used during system startup to avoid
@@ -944,9 +975,10 @@ public interface StreamEndpointBuilderFactory {
          * Syntax: <code>stream:kind</code>
          * 
          * Path parameter: kind (required)
          * Kind of stream to use such as System.in or System.out.
          * There are 5 enums and the value can be one of: in, out, err, header,
          * file
          * 
          * @param path kind
          * @return the dsl builder
@@ -965,9 +997,10 @@ public interface StreamEndpointBuilderFactory {
          * Syntax: <code>stream:kind</code>
          * 
          * Path parameter: kind (required)
          * Kind of stream to use such as System.in or System.out.
          * There are 5 enums and the value can be one of: in, out, err, header,
          * file
          * 
          * @param componentName to use a custom component name for the endpoint
          * instead of the default name
@@ -944,9 +975,10 @@ public interface StreamEndpointBuilderFactory {
          * 
          * Path parameter: kind (required)
-         * Kind of stream to use such as System.in or System.out.
-         * There are 5 enums and the value can be one of: in, out, err, header,
-         * file
+         * Kind of stream to use such as System.in, System.out, a file, or a
+         * http url.
+         * There are 6 enums and the value can be one of: in, out, err, header,
+         * file, http
          * 
          * @param path kind
@@ -965,9 +997,10 @@ public interface StreamEndpointBuilderFactory {
          * 
          * Path parameter: kind (required)
-         * Kind of stream to use such as System.in or System.out.
-         * There are 5 enums and the value can be one of: in, out, err, header,
-         * file
+         * Kind of stream to use such as System.in, System.out, a file, or a
+         * http url.
+         * There are 6 enums and the value can be one of: in, out, err, header,
+         * file, http
          * 
          * @param componentName to use a custom component name for the endpoint